declare const _default = "// VTL 2.0 06/2020 SDMX\n// Remove component duplication\n// Add distance operators (levenshtein)\n\ngrammar Vtl;\nimport VtlTokens;\n\nstart:\n    (statement  EOL)* EOF\n;\n\n/* statement */\nstatement:\n    varID ASSIGN expr                # temporaryAssignment\n    | varID PUT_SYMBOL expr          # persistAssignment\n    | defOperators                   # defineExpression\n;\n\n/* expression */\nexpr:\n    LPAREN expr RPAREN\t\t\t\t\t\t\t\t\t\t\t            # parenthesisExpr\n    | functions                                                             # functionsExpression\n    | dataset=expr  QLPAREN  clause=datasetClause  QRPAREN                  # clauseExpr\n    | expr MEMBERSHIP simpleComponentId                                     # membershipExpr\n    | op=(PLUS|MINUS|NOT) right=expr                                        # unaryExpr\n    | left=expr op=(MUL|DIV) right=expr                                     # arithmeticExpr\n    | left=expr op=(PLUS|MINUS|CONCAT) right=expr                           # arithmeticExprOrConcat\n    | left=expr op=comparisonOperand  right=expr                            # comparisonExpr\n    | left=expr op=(IN|NOT_IN)(lists|valueDomainID)                         # inNotInExpr\n    | left=expr op=AND right=expr                                           # booleanExpr\n    | left=expr op=(OR|XOR) right=expr\t\t\t\t\t\t\t            # booleanExpr\n    | IF  conditionalExpr=expr  THEN thenExpr=expr ELSE elseExpr=expr       # ifExpr\n    | constant\t\t\t\t\t\t\t\t\t\t\t\t\t\t        # constantExpr\n    | varID\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t        # varIdExpr\n\n\n;\n\n\n//exprComponent:\n//    LPAREN exprComponent RPAREN                                                                             # parenthesisExprComp\n//    | functionsComponents                                                                                   # functionsExpressionComp\n//    | op=(PLUS|MINUS|NOT) right=exprComponent                                                               # unaryExprComp\n//    | left=exprComponent op=(MUL|DIV) right=exprComponent                                                   # arithmeticExprComp\n//    | left=exprComponent op=(PLUS|MINUS|CONCAT) right=exprComponent                                         # arithmeticExprOrConcatComp\n//    | left=exprComponent comparisonOperand right=exprComponent                                              # comparisonExprComp\n//    | left=exprComponent op=(IN|NOT_IN)(lists|valueDomainID)                                                # inNotInExprComp\n//    | left=exprComponent op=AND right=exprComponent                                                         # booleanExprComp\n//    | left=exprComponent op=(OR|XOR) right=exprComponent                                                    # booleanExprComp\n//    | IF  conditionalExpr=exprComponent  THEN thenExpr=exprComponent ELSE elseExpr=exprComponent            # ifExprComp\n//    | constant                                                                                              # constantExprComp\n//    | componentID                                                                                           # compId\n//;\n\n//functionsComponents:\n//    genericOperatorsComponent           # genericFunctionsComponents\n//   | stringOperatorsComponent           # stringFunctionsComponents\n//   | numericOperatorsComponent          # numericFunctionsComponents\n//   | comparisonOperatorsComponent       # comparisonFunctionsComponents\n//   | timeOperatorsComponent             # timeFunctionsComponents\n//   | conditionalOperatorsComponent      # conditionalFunctionsComponents\n//   | aggrOperators                      # aggregateFunctionsComponents\n//   | anFunctionComponent                # analyticFunctionsComponents\n//\n//;\n\n/* functions */\nfunctions:\n    joinOperators                       # joinFunctions\n    | genericOperators                  # genericFunctions\n    | stringOperators                   # stringFunctions\n    | numericOperators                  # numericFunctions\n    | comparisonOperators               # comparisonFunctions\n    | timeOperators                     # timeFunctions\n    | setOperators                      # setFunctions\n    | hierarchyOperators                # hierarchyFunctions\n    | validationOperators               # validationFunctions\n    | conditionalOperators              # conditionalFunctions\n    | aggrOperatorsGrouping             # aggregateFunctions\n    | anFunction                        # analyticFunctions\n    | distanceOperators                 # distanceFunctions\n;\n\n\n/*------------------------------------------------------ Clauses----------------------------------------------- */\ndatasetClause:\n    renameClause\n    | aggrClause\n    | filterClause\n    | calcClause\n    | keepOrDropClause\n    | pivotOrUnpivotClause\n    | customPivotClause\n    | subspaceClause\n;\n\nrenameClause:\n    RENAME renameClauseItem (COMMA renameClauseItem)*\n;\n\naggrClause:\n    AGGREGATE aggregateClause (groupingClause havingClause?)?\n;\n\nfilterClause:\n    FILTER expr\n;\n\ncalcClause:\n    CALC calcClauseItem (COMMA calcClauseItem)*\n;\n\nkeepOrDropClause:\n    op = (KEEP | DROP) componentID (COMMA componentID)*\n;\n\n\npivotOrUnpivotClause:\n    op=(PIVOT|UNPIVOT) id_=componentID COMMA mea=componentID\n;\n\ncustomPivotClause:\n    CUSTOMPIVOT id_=componentID COMMA mea=componentID IN constant (COMMA constant)*\n;\n\nsubspaceClause:\n    SUBSPACE subspaceClauseItem (COMMA subspaceClauseItem)*\n;\n\n/*------------------------------------------------------End Clauses----------------------------------------------- */\n\n/************************************************** JOIN FUNCITONS -------------------------------------------*/\n\njoinOperators:\n     joinKeyword=(INNER_JOIN | LEFT_JOIN) LPAREN joinClause joinBody RPAREN                                     # joinExpr\n     | joinKeyword=(FULL_JOIN | CROSS_JOIN) LPAREN joinClauseWithoutUsing joinBody RPAREN                       # joinExpr\n;\n\n/************************************************** END JOIN FUNCITONS -------------------------------------------*/\n/* --------------------------------------------Define Functions------------------------------------------------- */\ndefOperators:\n    DEFINE OPERATOR operatorID LPAREN (parameterItem (COMMA parameterItem)*)? RPAREN (RETURNS outputParameterType)? IS (expr) END OPERATOR        # defOperator\n    | DEFINE DATAPOINT RULESET rulesetID LPAREN rulesetSignature RPAREN IS ruleClauseDatapoint END DATAPOINT RULESET                            # defDatapointRuleset\n    | DEFINE HIERARCHICAL RULESET rulesetID LPAREN hierRuleSignature RPAREN IS ruleClauseHierarchical  END HIERARCHICAL RULESET                 # defHierarchical\n;\n\n/* --------------------------------------------END DEFINE FUNCTIONS------------------------------------------------- */\n\n/*---------------------------------------------------FUNCTIONS-------------------------------------------------*/\ngenericOperators:\n    operatorID LPAREN (parameter (COMMA parameter)*)? RPAREN                                                                                                                    # callDataset\n    | EVAL LPAREN routineName LPAREN (varID|constant)? (COMMA (varID|constant))* RPAREN (LANGUAGE STRING_CONSTANT)? (RETURNS datasetType)? RPAREN                               # evalAtom\n    | CAST LPAREN expr COMMA (basicScalarType|valueDomainName) (COMMA STRING_CONSTANT)? RPAREN                                                                                  # castExprDataset\n;\n\n//genericOperatorsComponent:\n//    operatorID LPAREN (parameterComponent (COMMA parameterComponent)*)? RPAREN                                  # callComponent\n//    | CAST LPAREN exprComponent COMMA (basicScalarType|valueDomainName) (COMMA STRING_CONSTANT)? RPAREN         # castExprComponent\n//    | EVAL LPAREN routineName LPAREN (componentID|constant)? (COMMA (componentID|constant))* RPAREN (LANGUAGE STRING_CONSTANT)? (RETURNS outputParameterTypeComponent)? RPAREN      # evalAtomComponent\n//;\n\n\n//parameterComponent:\n//    componentID\n//    | constant\n//    | OPTIONAL\n//;\n\nparameter:\n    varID\n    | constant\n    | OPTIONAL\n;\n\nstringOperators:\n    op=(TRIM | LTRIM | RTRIM | UCASE | LCASE | LEN) LPAREN expr RPAREN\t                                    # unaryStringFunction\n    | SUBSTR LPAREN expr (((COMMA startParameter=optionalExpr) (COMMA endParameter=optionalExpr))? | COMMA startParameter=optionalExpr ) RPAREN     # substrAtom\n    | REPLACE LPAREN expr COMMA param=expr ( COMMA optionalExpr)? RPAREN\t\t\t\t                    # replaceAtom\n    | INSTR LPAREN expr COMMA pattern=expr ( COMMA startParameter=optionalExpr)? (COMMA occurrenceParameter=optionalExpr)? RPAREN\t            # instrAtom\n;\n\n//stringOperatorsComponent:\n//    op=(TRIM | LTRIM | RTRIM | UCASE | LCASE | LEN) LPAREN exprComponent RPAREN\t                                                    # unaryStringFunctionComponent\n//    | SUBSTR LPAREN exprComponent (((COMMA startParameter=optionalExprComponent) (COMMA endParameter=optionalExprComponent))? | COMMA startParameter=optionalExprComponent )  RPAREN  # substrAtomComponent\n//    | REPLACE LPAREN exprComponent COMMA param=exprComponent ( COMMA optionalExprComponent)? RPAREN                                 # replaceAtomComponent\n//    | INSTR LPAREN exprComponent COMMA pattern=exprComponent ( COMMA startParameter=optionalExprComponent)? (COMMA occurrenceParameter=optionalExprComponent)? RPAREN    # instrAtomComponent\n//;\n\nnumericOperators:\n    op=(CEIL | FLOOR | ABS | EXP | LN | SQRT) LPAREN expr RPAREN\t\t\t\t\t\t        # unaryNumeric\n    | op=(ROUND | TRUNC) LPAREN expr (COMMA optionalExpr)? RPAREN\t\t\t\t\t\t\t    # unaryWithOptionalNumeric\n    | op=(MOD | POWER|LOG) LPAREN left=expr COMMA right=expr RPAREN\t\t\t\t\t\t\t    # binaryNumeric\n;\n\n//numericOperatorsComponent:\n//    op=(CEIL | FLOOR | ABS | EXP | LN | SQRT) LPAREN exprComponent RPAREN\t\t\t\t\t\t# unaryNumericComponent\n//    | op=(ROUND | TRUNC) LPAREN exprComponent (COMMA optionalExprComponent)? RPAREN\t\t\t    # unaryWithOptionalNumericComponent\n//    | op=(MOD | POWER | LOG) LPAREN left=exprComponent COMMA right=exprComponent RPAREN\t\t    # binaryNumericComponent\n//;\n\ncomparisonOperators:\n     BETWEEN LPAREN op=expr COMMA from_=expr COMMA to_=expr RPAREN\t                    # betweenAtom\n    | CHARSET_MATCH LPAREN op=expr COMMA  pattern=expr RPAREN\t\t\t\t\t\t\t    # charsetMatchAtom\n    | ISNULL LPAREN expr RPAREN\t\t\t\t\t\t\t\t\t\t\t\t                # isNullAtom\n    | EXISTS_IN LPAREN left=expr COMMA right=expr (COMMA retainType)? RPAREN                # existInAtom\n;\n\n//comparisonOperatorsComponent:\n//     BETWEEN LPAREN op=exprComponent COMMA from_=exprComponent COMMA to_=exprComponent RPAREN    # betweenAtomComponent\n//    | CHARSET_MATCH LPAREN op=exprComponent COMMA  pattern=exprComponent RPAREN                     # charsetMatchAtomComponent\n//    | ISNULL LPAREN exprComponent RPAREN                                                            # isNullAtomComponent\n//;\n\ntimeOperators:\n    PERIOD_INDICATOR LPAREN expr? RPAREN                                                                                                # periodAtom\n    | FILL_TIME_SERIES LPAREN expr (COMMA (SINGLE|ALL))? RPAREN                                                                         # fillTimeAtom\n    | op=(FLOW_TO_STOCK | STOCK_TO_FLOW) LPAREN expr RPAREN\t                                                                            # flowAtom\n    | TIMESHIFT LPAREN expr COMMA signedInteger RPAREN                                                                                  # timeShiftAtom\n    | TIME_AGG LPAREN periodIndTo=STRING_CONSTANT (COMMA periodIndFrom=(STRING_CONSTANT| OPTIONAL ))? (COMMA op=optionalExpr)? (COMMA (FIRST|LAST))? RPAREN     # timeAggAtom\n    | CURRENT_DATE LPAREN RPAREN                                                                                                        # currentDateAtom\n;\n\n//timeOperatorsComponent:\n//    PERIOD_INDICATOR LPAREN exprComponent? RPAREN                                                                                               # periodAtomComponent\n//    | FILL_TIME_SERIES LPAREN exprComponent (COMMA (SINGLE|ALL))? RPAREN                                                                        # fillTimeAtomComponent\n//    | op=(FLOW_TO_STOCK | STOCK_TO_FLOW) LPAREN exprComponent RPAREN\t                                                                                    # flowAtomComponent\n//    | TIMESHIFT LPAREN exprComponent COMMA signedInteger RPAREN                                                                                 # timeShiftAtomComponent\n//    | TIME_AGG LPAREN periodIndTo=STRING_CONSTANT (COMMA periodIndFrom=(STRING_CONSTANT| OPTIONAL ))? (COMMA op=optionalExprComponent)? (COMMA (FIRST|LAST))? RPAREN    # timeAggAtomComponent\n//    | CURRENT_DATE LPAREN RPAREN                                                                                                                # currentDateAtomComponent\n//;\n\nsetOperators:\n    UNION LPAREN left=expr (COMMA expr)+ RPAREN                             # unionAtom\n    | INTERSECT LPAREN left=expr (COMMA expr)+ RPAREN                       # intersectAtom\n    | op=(SETDIFF|SYMDIFF) LPAREN left=expr COMMA right=expr RPAREN         # setOrSYmDiffAtom\n;\n/* hierarchy */\nhierarchyOperators:\n    HIERARCHY LPAREN op=expr COMMA hrName=IDENTIFIER (conditionClause)? (RULE ruleComponent=componentID)? (validationMode)? (inputModeHierarchy)? outputModeHierarchy? RPAREN\n;\n\nvalidationOperators:\n  CHECK_DATAPOINT LPAREN op=expr COMMA dpName=IDENTIFIER (COMPONENTS componentID (COMMA componentID)*)? validationOutput? RPAREN\t\t\t\t\t\t\t\t\t\t# validateDPruleset\n  | CHECK_HIERARCHY LPAREN op=expr COMMA hrName=IDENTIFIER conditionClause? (RULE componentID)? validationMode? inputMode? validationOutput? RPAREN \t                # validateHRruleset\n  | CHECK LPAREN op=expr (codeErr=erCode)? (levelCode=erLevel)? imbalanceExpr?  output=(INVALID|ALL)? RPAREN\t\t\t\t\t\t\t\t\t\t\t\t\t        # validationSimple\n;\n\nconditionalOperators:\n    NVL LPAREN left=expr COMMA right = expr RPAREN\t\t\t\t\t\t\t# nvlAtom\n;\n\n//conditionalOperatorsComponent:\n//    NVL LPAREN left=exprComponent COMMA right = exprComponent RPAREN        # nvlAtomComponent\n//;\n\n//aggrOperators:\n//    op =(SUM\n//    | AVG\n//    | COUNT\n//    | MEDIAN\n//    | MIN\n//    | MAX\n//    | STDDEV_POP\n//    | STDDEV_SAMP\n//    | VAR_POP\n//    | VAR_SAMP) LPAREN exprComponent RPAREN                    # aggrComp\n//    | COUNT LPAREN RPAREN               # countAggrComp\n//\n//;\n\n\naggrOperatorsGrouping:\n    op =(SUM\n        | AVG\n        | COUNT\n        | MEDIAN\n        | MIN\n        | MAX\n        | STDDEV_POP\n        | STDDEV_SAMP\n        | VAR_POP\n        | VAR_SAMP) LPAREN expr (groupingClause havingClause?)? RPAREN  #aggrDataset\n\n;\n\n anFunction:\n    op = ( SUM\n        | AVG\n        | COUNT\n        | MEDIAN\n        | MIN\n        | MAX\n        | STDDEV_POP\n        | STDDEV_SAMP\n        | VAR_POP\n        | VAR_SAMP\n        | FIRST_VALUE\n        | LAST_VALUE)\n        LPAREN expr OVER LPAREN (partition=partitionByClause? orderBy=orderByClause? windowing=windowingClause?)RPAREN RPAREN       #anSimpleFunction\n    | op=(LAG |LEAD)  LPAREN expr (COMMA offet=signedInteger(defaultValue=constant)?)?  OVER  LPAREN (partition=partitionByClause? orderBy=orderByClause)   RPAREN RPAREN    # lagOrLeadAn\n    | op=RATIO_TO_REPORT LPAREN expr OVER  LPAREN (partition=partitionByClause) RPAREN RPAREN                                                                           # ratioToReportAn\n;\n\n// anFunctionComponent:\n//   op = ( SUM\n//         | AVG\n//         | COUNT\n//         | MEDIAN\n//         | MIN\n//         | MAX\n//         | STDDEV_POP\n//         | STDDEV_SAMP\n//         | VAR_POP\n//         | VAR_SAMP\n//         | FIRST_VALUE\n//         | LAST_VALUE)\n//         LPAREN exprComponent OVER LPAREN (partition=partitionByClause? orderBy=orderByClause? windowing=windowingClause?)RPAREN RPAREN       #anSimpleFunctionComponent\n//    | op=(LAG |LEAD)  LPAREN exprComponent (COMMA offet=signedInteger(defaultValue=constant)?)?  OVER  LPAREN (partition=partitionByClause? orderBy=orderByClause)   RPAREN RPAREN   # lagOrLeadAnComponent\n//    | op=RANK LPAREN  OVER  LPAREN (partition=partitionByClause? orderBy=orderByClause) RPAREN RPAREN                                                                           # rankAnComponent\n//    | op=RATIO_TO_REPORT LPAREN exprComponent OVER  LPAREN (partition=partitionByClause) RPAREN RPAREN                                                                          # ratioToReportAnComponent\n//;\n\ndistanceOperators:\n    LEVENSHTEIN LPAREN left=expr COMMA right=expr RPAREN    # levenshteinAtom\n;\n/*---------------------------------------------------END FUNCTIONS-------------------------------------------------*/\n\n/*-------------------------------------------------CLAUSE EXPRESSION------------------------------------------------*/\n/*RENAME CLAUSE */\nrenameClauseItem:\n    fromName=componentID TO toName=componentID\n;\n\n/*END RENAME CLAUSE*/\n\n/*AGGR CLAUSE*/\naggregateClause:\n    aggrFunctionClause (COMMA aggrFunctionClause)*\n;\n\naggrFunctionClause:\n    (componentRole)? componentID  ASSIGN  aggrOperatorsGrouping\n;\n/*END AGGR CLAUSE*/\n\n/*CALC CLAUSE*/\ncalcClauseItem:\n    (componentRole)? componentID  ASSIGN  expr\n;\n/*END CALC CLAUSE*/\n\n/*SUBSPACE CLAUSE*/\nsubspaceClauseItem\n  :\n  componentID  EQ  constant\n  ;\n/*END SUBSPACE CLAUSE*/\n/*----------------------------------------------END CLAUSE EXPRESSION--------------------------------------*/\n\n/*---------------------------------------------JOIN CLAUSE EXPRESSION---------------------------------------*/\n\njoinClauseWithoutUsing:\n    joinClauseItem (COMMA joinClauseItem)*\n;\n\njoinClause:\n    joinClauseItem (COMMA joinClauseItem)* (USING componentID (COMMA componentID)*)?\n;\n\njoinClauseItem:\n    expr (AS alias)?\n;\n\njoinBody:\n    filterClause? (calcClause|joinApplyClause|aggrClause)? (keepOrDropClause)? renameClause?\n;\n\n/* JOIN APPLY CLAUSE*/\njoinApplyClause:\n    APPLY expr\n;\n/* END JOIN APPLY CLAUSE*/\n\n/*---------------------------------------------END JOIN CLAUSE EXPRESSION---------------------------------------*/\n\n/*-----------------------------------------ANALYTIC CLAUSE -----------------------------------------------*/\n\npartitionByClause:\n    PARTITION BY componentID (COMMA componentID)*\n;\n\norderByClause:\n    ORDER BY orderByItem (COMMA orderByItem)*\n;\n\norderByItem:\n    componentID (ASC|DESC)?\n;\n\nwindowingClause:\n    ((DATA POINTS)|RANGE) BETWEEN from_=limitClauseItem AND to_=limitClauseItem\n;\n\nsignedInteger:\n  INTEGER_CONSTANT\n;\n\nlimitClauseItem:\n    INTEGER_CONSTANT PRECEDING\n    | INTEGER_CONSTANT FOLLOWING\n    | CURRENT DATA POINT\n    | UNBOUNDED PRECEDING\n    | UNBOUNDED FOLLOWING\n;\n\n/*--------------------------------------------END ANALYTIC CLAUSE -----------------------------------------------*/\n/* ------------------------------------------------------------ GROUPING CLAUSE ------------------------------------*/\ngroupingClause:\n    GROUP op=(BY | EXCEPT) componentID (COMMA componentID)*     # groupByOrExcept\n    | GROUP ALL expr                                            # groupAll\n  ;\n\nhavingClause:\n  HAVING expr\n  ;\n/*-------------------------------------------END GROUPING CLAUSE-----------------------------------------------------*/\n\n/*------------------------------------------------DEFINE OPERATOR ---------------------------------------------------*/\n\nparameterItem:\n    varID inputParameterType (DEFAULT constant)?\n;\n\noutputParameterType:\n    scalarType\n    | datasetType\n    | componentType\n;\n\noutputParameterTypeComponent:\n    componentType\n    |scalarType\n;\n\ninputParameterType:\n    scalarType\n    | datasetType\n    | scalarSetType\n    | rulesetType\n    | componentType\n;\n\nrulesetType:\n    RULESET\n    | dpRuleset\n    | hrRuleset\n;\n\nscalarType:\n    (basicScalarType|valueDomainName)scalarTypeConstraint?((NOT)? NULL_CONSTANT)?\n;\n\ncomponentType:\n    componentRole ( LT   scalarType  MT  )?\n;\n\ndatasetType:\n    DATASET ( GLPAREN compConstraint (COMMA compConstraint)*  GRPAREN  )?\n;\n\n\nscalarSetType:\n    SET ( LT   scalarType  MT  )?\n;\n\ndpRuleset:\n    DATAPOINT                                                                               # dataPoint\n    | DATAPOINT_ON_VD  (GLPAREN  valueDomainName (MUL valueDomainName)*  GRPAREN )?         # dataPointVd\n    | DATAPOINT_ON_VAR  (GLPAREN  varID (MUL varID)*  GRPAREN )?                            # dataPointVar\n;\n\nhrRuleset:\n    HIERARCHICAL                                                                                                            # hrRulesetType\n    | HIERARCHICAL_ON_VD ( GLPAREN  vdName=IDENTIFIER (LPAREN valueDomainName (MUL valueDomainName)* RPAREN)?  GRPAREN )?   # hrRulesetVdType\n    | HIERARCHICAL_ON_VAR ( GLPAREN  varName=varID (LPAREN  varID (MUL varID)* RPAREN)?  GRPAREN )?                         # hrRulesetVarType\n;\n\nvalueDomainName:\n    IDENTIFIER\n;\n\nrulesetID:\n    IDENTIFIER\n;\n\nrulesetSignature:\n    (VALUE_DOMAIN|VARIABLE) signature (COMMA signature)*\n;\n\nsignature:\n    varID (AS alias)?\n;\n\nruleClauseDatapoint:\n    ruleItemDatapoint ( EOL  ruleItemDatapoint)*\n;\n\nruleItemDatapoint:\n    (ruleName=IDENTIFIER  COLON )? ( WHEN antecedentContiditon=expr THEN )? consequentCondition=expr (erCode)? (erLevel)?\n;\n\nruleClauseHierarchical:\n    ruleItemHierarchical ( EOL  ruleItemHierarchical)*\n ;\n\nruleItemHierarchical:\n    (ruleName=IDENTIFIER  COLON )? codeItemRelation (erCode)? (erLevel)?\n ;\n\n hierRuleSignature:\n    (VALUE_DOMAIN|VARIABLE) (CONDITION valueDomainSignature)? RULE IDENTIFIER\n ;\n\n valueDomainSignature:\n    signature (COMMA signature)*\n ;\n\ncodeItemRelation:\n    ( WHEN expr THEN )? codetemRef=valueDomainValue comparisonOperand? codeItemRelationClause (codeItemRelationClause)*\n;\n\ncodeItemRelationClause:\n    (opAdd=( PLUS | MINUS  ))? rightCodeItem=valueDomainValue ( QLPAREN  rightCondition=expr  QRPAREN )?\n;\n\nvalueDomainValue:\n    IDENTIFIER\n    | INTEGER_CONSTANT\n    | NUMBER_CONSTANT\n;\n\nscalarTypeConstraint:\n    QLPAREN  expr  QRPAREN                     # conditionConstraint\n    | GLPAREN  constant (COMMA constant)*  GRPAREN      # rangeConstraint\n;\n\n\ncompConstraint:\n    componentType (componentID|multModifier)\n;\n\nmultModifier:\n    OPTIONAL  ( PLUS | MUL )?\n;\n\n/*--------------------------------------------END DEFINE OPERATOR ---------------------------------------------------*/\n\n\n/*------------------------------------------VALIDATION OPERATOR ---------------------------------------------------*/\nvalidationOutput:\n    INVALID|ALL_MEASURES|ALL\n;\n\nvalidationMode:\n    NON_NULL|NON_ZERO|PARTIAL_NULL|PARTIAL_ZERO|ALWAYS_NULL|ALWAYS_ZERO\n;\n\nconditionClause:\n    CONDITION componentID (COMMA componentID)*\n;\n\ninputMode:\n    DATASET|DATASET_PRIORITY\n;\n\nimbalanceExpr:\n    IMBALANCE expr\n;\n\ninputModeHierarchy:\n    RULE|DATASET|RULE_PRIORITY\n;\n\noutputModeHierarchy:\n    COMPUTED|ALL\n;\n/*--------------------------------------END VALIDATION OPERATOR ---------------------------------------------------*/\nalias:\n    IDENTIFIER\n;\n\nvarID:\n    IDENTIFIER\n;\n\nsimpleComponentId:\n    IDENTIFIER\n;\n\ncomponentID:\n   IDENTIFIER (MEMBERSHIP IDENTIFIER)?\n;\n\nlists:\n    GLPAREN  constant (COMMA constant)*  GRPAREN\n;\n\nerCode:\n    ERRORCODE  constant\n;\n\nerLevel:\n    ERRORLEVEL  constant\n;\n\ncomparisonOperand:\n    MT\n    | ME\n    | LE\n    | LT\n    | EQ\n    | NEQ\n;\n\n/* Conditional */\noptionalExpr:\n    expr\n    | OPTIONAL\n;\n\n//optionalExprComponent:\n//    exprComponent\n//    | OPTIONAL\n//;\n/* Role name*/\ncomponentRole:\n    MEASURE\n    | COMPONENT\n    | DIMENSION\n    | ATTRIBUTE\n    | viralAttribute\n;\n\nviralAttribute:\n    VIRAL ATTRIBUTE\n;\n\nvalueDomainID:\n    IDENTIFIER\n    ;\n\noperatorID:\n    IDENTIFIER\n;\n\nroutineName:\n    IDENTIFIER\n;\n\nconstant:\n    INTEGER_CONSTANT\n    | NUMBER_CONSTANT\n    | BOOLEAN_CONSTANT\n    | STRING_CONSTANT\n    | NULL_CONSTANT\n;\n\nbasicScalarType:\n    STRING\n    | INTEGER\n    | NUMBER\n    | BOOLEAN\n    | DATE\n    | TIME\n    | TIME_PERIOD\n    | DURATION\n    | SCALAR\n\n;\n\nretainType:\n    BOOLEAN_CONSTANT\n    | ALL\n;";
export default _default;
